@@ -17,6 +17,8 @@ class Ks3Oss:
         if not kwargs.get("host"):
             kwargs.update({"host": tornado.options.options.ks3_connect_config.get("host")})
         bucket_name = kwargs.pop("bucket_name", None)
+        if bucket_name is None:
+            bucket_name = tornado.options.options.ks3_connect_config.get("bucket_name")
         self.client = Connection(**kwargs)
         if bucket_name is not None:
             self.instance = self.client.get_bucket(bucket_name)
