@@ -10,6 +10,7 @@ import logging
 import time
 import traceback
 import types
+import uuid
 from datetime import datetime
 from decimal import Decimal
 from typing import Optional, Awaitable, Any
@@ -21,6 +22,7 @@ from tornado.escape import utf8
 from tornado.ioloop import IOLoop
 from tornado.web import RequestHandler, Application
 
+from lesscode.task.task_helper import TaskHelper
 from lesscode.utils.es_log.record_log import es_record_log
 from lesscode.web.status_code import StatusCode
 from lesscode.web.business_exception import BusinessException
@@ -232,6 +234,10 @@ class BaseHandler(RequestHandler):
                 self.end_time = int(round(time.time() * 1000))
                 self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
                 self.process_response(data)
+                task_id = uuid.uuid1().hex
+                TaskHelper.add_job(es_record_log, id=task_id, name=task_id,
+                                   kwargs={"request": self.request, "message": "", "level": "info",
+                                           "status_code": "00000", "task_id": task_id})
             except Exception as e:
                 self.process_exception(e)
 
@@ -272,7 +278,10 @@ class BaseHandler(RequestHandler):
         :param kwargs:
         :return:
         """
-        es_record_log(request=self.request, message=traceback.format_exc(), level="error", status_code=status_code)
+        task_id = uuid.uuid1().hex
+        TaskHelper.add_job(es_record_log, id=task_id, name=task_id,
+                           kwargs={"request": self.request, "message": traceback.format_exc(), "level": "error",
+                                   "status_code": status_code, "task_id": task_id})
         error = kwargs["exc_info"]
         if isinstance(error[1], BusinessException):
             self.set_status(200)
